from setuptools import setup
setup(name='decorrators',
      version='0.1.1.1b',
      description='this is a python library with cool decorators',
      packages=['decorators'],
      author_email='vanshnir@gmail.com',
      zip_safe=False)